package com.corejdo.casestudy.model;

import java.util.Date;

/**
 * A copy is the instance of a publication in a library. A copy
 * can be located somewhere in the library or it can be borrowed by someone.
 * Other states of a copy can be: missing, damaged or sold.
 * A copy cannot be reserved by someone, only publications can be reserved.
 *
 * <BR><FONT Color="red"><B>Persistent</B></FONT>
 * @author Heiko Bobzin, Keiron McCammon, Sameer Tyagi, Michael Vorburger
 * @version 1.0
 */

public class Copy
{
    /**
     * The publication of which this is the instance of.
     */
    public Publication copyOf;

    /**
     * This flag is set, when the borrowing time is over.
     */
    public boolean missing;
    /**
     * If the copy is damaged, this flag is set.
     */
    public boolean damaged;
    /**
     * If someone bought the copy, this flag is set.
     */
    public boolean sold;
    /**
     * Location decribing the place of the copy in the library.
     */
    public String location;
    /**
     * Reference to the borrower. If set, this publication instance is borrowed
     * by someone.
     */
    public User borrower;
    /**
     * Date when the copy was borrowed. Depending on the user policies of the
     * library.
     */
    public Date borrowDate;
    /**
     * Date when the copy should be returned to the library.
     */
    public Date returnDate;

    public Copy(Publication copyOf)
    {
        this.copyOf = copyOf;
        this.location = "entry";
    }

    private Copy()
    {
    }

}