package com.corejdo.casestudy.model;
import java.util.Date;
import java.util.Collection;
import javax.jdo.*;

/**
 * This class contains generic information common to all sorts of
 * publications.
 *
 * <BR><FONT Color="red"><B>Persistent</B></FONT>
 * @author Heiko Bobzin, Keiron McCammon, Sameer Tyagi, Michael Vorburger
 * @version 1.0
 */
public abstract class Publication
{
    /**
     * The title of the publication.
     */
    public String title;
    /**
     * Date, when the publication was published.
     */
    public Date published;
    /**
     * Date, when the publication was first published.
     */
    public Date firstPublished;
    /**
     * A copyright text.
     */
    public String copyright;

    /**
     * The librarian who maintained the publication.
     */
    public User insertedBy;

    public Publication() {
    }

    public String toString()
    {
        return "\n Title: "+title+
        "\n Published: "+published+
        "\n First published: "+firstPublished+
        "\n Copyright: "+copyright;
    }

    public String toHTMLTitle(String linkPrefix)
    {
        return "<TD CLASS=pubTitle>"+title+"</TD>";
    }

    public String toHTMLRest(String linkPrefix)
    {
        return
        "<TD CLASS=pubPubFirst>"+firstPublished+"</TD>"+
        "<TD CLASS=pubCopyright>"+copyright+"</TD>";
    }

    public abstract String toHTML(String linkPrefix);

    /**
     */
    public Copy[] getCopies()
    {
        PersistenceManager pm = JDOHelper.getPersistenceManager(this);
        // find the copy
        Query q = pm.newQuery(Copy.class, "copyOf == val");
        q.declareParameters("com.corejdo.casestudy.model.Publication val");
        q.setCandidates(pm.getExtent(Copy.class,true));
        Collection result = (Collection)q.execute(this);
        Copy[] copies = new Copy[result.size()];
        result.toArray(copies);
        return copies;
    }


}