package com.corejdo.casestudy.model;

import javax.jdo.InstanceCallbacks;
import javax.jdo.JDOHelper;
/**
 * Defines access restrictions for users and user groups of the library.
 *
 * This is an example for a type mapping: Instead of defining another persistent
 * class Right, the tri-state values (allow, deny, default) are coded into plain
 * integer values, (+1, -1, 0 respectively). For a better programming model, the
 * Right class is exposed to the application, but stored internally as integer
 * values.
 *
 * <BR><FONT Color="red"><B>Persistent</B></FONT>
 * @author Heiko Bobzin, Keiron McCammon, Sameer Tyagi, Michael Vorburger
 * @version 1.0
 */
public class Rights
    implements Cloneable
{
    /**
     * The right to add, remove or modify users of the library.
     */
    private int _modifyUser;

    /**
     * The right to borrow something.
     */
    private int _borrow;

    /**
     * The right to manage publications.
     */
    private int _manage;



    /**
     * The constructor creates an default Rights object.
     * (An unauthorized user.)
     */

    public Rights()
    {
    }

    private int rightToInt(Right r)
    {
        if (r == Right.ALLOWED) return 1;
        if (r == Right.DEFAULT) return 0;
        if (r == Right.DENIED) return -1;
        throw new RuntimeException("Illegal value: "+r);
    }

    private Right intToRight(int i)
    {
        if (i == 1) return Right.ALLOWED;
        if (i == 0) return Right.DEFAULT;
        if (i == -1) return Right.DENIED;
        throw new RuntimeException("Illegal value: "+i);
    }

    public boolean canBorrow()
    {
        return intToRight(_borrow).isAllowed(Right.ALLOWED);
    }
    public boolean canManage()
    {
        return intToRight(_manage).isAllowed(Right.DENIED);
    }
    public boolean canModifyUser()
    {
        return intToRight(_modifyUser).isAllowed(Right.DENIED);
    }

    public void setBorrow(Right r)
    {
        _borrow = rightToInt(r);
    }

    public void setManage(Right r)
    {
        _manage = rightToInt(r);
    }

    public void setModifyUser(Right r)
    {
        _modifyUser = rightToInt(r);
    }

    public Rights copy()
    {
        try {
            int k = this._borrow;
            Rights r = (Rights)this.clone();
            return r;
        }
        catch (CloneNotSupportedException c) {
            throw new RuntimeException("Unexpected: "+c);
        }
    }

    public String toString()
    {
        String res =
         ( canBorrow() ? "borrow" : "noborrow")+
         ( canManage() ? ",manage" : ",nomanage")+
         ( canModifyUser() ? ",modify" : ",nomodify");
        return res;
    }
}