package com.corejdo.casestudy.tools;
import java.io.*;
import java.util.*;
import java.text.DateFormat;
/**
 * Utility methods to work with console applications.
 *
 * @author Heiko Bobzin, Keiron McCammon, Sameer Tyagi, Michael Vorburger
 * @version 1.0
 */

public class CmdLine {

    public CmdLine() {

    }

    /**
     * Tests the CmdLine class
     */
    public static void main(String args[])
    {
        String ret = getStringVar("Name","Heiko");
        System.out.println("return '"+ret+"'");
    }

    private static Properties argProps = new Properties();
    /**
     * Initializes from args.
     */
    public static void init(String args[])
    {
        for (int i = 0; i < args.length; i++)
        {
            StringTokenizer tok = new StringTokenizer(args[i],"=");
            if (tok.countTokens() == 2) {
                argProps.put(tok.nextToken(),tok.nextToken());
            }
        }
    }

    /**
     * Read an integer from console. If nothing is typed in,
     * the default value is returned.
     */
    public static int getIntVar(String prompt, int def)
    {
        int ret = Integer.parseInt(getStringVar(prompt,""+def));
        return ret;
    }

    /**
     * Read a boolean from console. If nothing is typed in,
     * the default value is returned.
     */
    public static boolean getBooleanVar(String prompt, boolean def)
    {
        String s = getStringVar(prompt,""+def);
        boolean ret = s.equalsIgnoreCase("true")
                || s.equalsIgnoreCase("yes");
        return ret;
    }

    /**
     * Read a date from console. If nothing is typed in,
     * the default value is returned.
     */
    public static Date getDateVar(String prompt, Date def)
    {
        Date ret = new Date();
        try {
            ret = DateFormat.getInstance().parse(getStringVar(prompt,""+def));
        }
        catch (java.text.ParseException pex)
        {
        }
        return ret;
    }

    /**
     * Reads a string from console. If nothing is typed in,
     * the default value is returned.
     */
    public static String getStringVar(String prompt, String def)
    {
        String argVal = argProps.getProperty(prompt);
        if (argVal != null) return argVal;
        if (def != null) {
            System.out.print(prompt+" ["+def+"]: ");
        } else {
            System.out.print(prompt+": ");
        }
        System.out.flush();
        BufferedReader r = new BufferedReader(new InputStreamReader(System.in));
        try {
            String line = r.readLine();
            if (line.length() == 0) line = def;
            return line;
        } catch (IOException iox) {
            throw new RuntimeException("No input. "+iox);
        }
    }
}