package com.corejdo.casestudy.usecase;

import com.corejdo.casestudy.model.Book;
import com.corejdo.casestudy.model.User;
import com.corejdo.casestudy.tools.CmdLine;

import java.util.Date;
import java.text.DateFormat;
import java.text.ParseException;

/**
 * This class adds a book to the library.
 * It implements a bean pattern, which can be used simply in the JSP.
 *
 * @author Heiko Bobzin, Keiron McCammon, Sameer Tyagi, Michael Vorburger
 * @version 1.0
 */

public class AddBook
    extends AbstractUseCase
{
    /**
     * This is the book that gets inserted. While it is transient, we
     * can set and get values directly.
     */
    Book book = new Book();

    public AddBook()
    {
    }

    public void setISBN(String ISBN)
    {
        book.ISBN = ISBN;
    }
    public void setAuthor(String author)
    {
        book.author = author;
    }
    public void setCopyright(String copyright)
    {
        book.copyright = copyright;
    }
    public void setPublished(String published)
    {
        book.published = parseDate(published);
    }
    public void setFirstPublished(String firstPublished)
    {
        book.firstPublished = parseDate(firstPublished);
    }

    public void setTitle(String title)
    {
        book.title = title;
    }

    /**
     * Adds a book via command line.
     */
    public static void main(String[] args) {
        new AddBook().runCmdLine(args);
    }

    protected void run(String[] args) {
        setTitle(CmdLine.getStringVar("Title",""));
        setISBN(CmdLine.getStringVar("ISBN",""));
        setAuthor(CmdLine.getStringVar("Author","Heiko Bobzin"));
        setCopyright(CmdLine.getStringVar("Copyright","(C) 2003 Prentice Hall"));
        String now = new Date().toString();
        setPublished(CmdLine.getStringVar("Publishing date",now));
        setFirstPublished(CmdLine.getStringVar("First publishing date",now));
        execute();
    }

    private Date parseDate(String d)
    {
        try {
            return DateFormat.getInstance().parse(d);
        }
        catch (ParseException e)
        {
            throw new RuntimeException("Illegal date: "+d);
        }
    }

    public boolean isAllowed()
    {
        return getContext().userRights.canManage();
    }

    protected void _execute()
    {
        // this is a really simple operation:
        User user = getUser();
        book.insertedBy = user;
        getPM().makePersistent(book);
        // set for next insert:
        book = new Book();
    }

    public String getFirstPublished()
    {
        return new Date().toString();
    }
    public String getPublished()
    {
        return new Date().toString();
    }
}