package com.corejdo.casestudy.usecase;

import com.corejdo.casestudy.model.*;
import javax.jdo.*;
import java.util.*;

/**
 * Basic class of all Book operations.
 * This class can find a single book.
 * @author Heiko Bobzin, Keiron McCammon, Sameer Tyagi, Michael Vorburger
 * @version 1.0
 */

public abstract class BookOperation extends AbstractUseCase
{

    public BookOperation()
    {
    }

    /**
     * Searches for a book that matches a string field
     * @param field name of field in the book class.
     * @param fieldValue value to match
     * @return a book
     */
    protected Book findBook(String field, String fieldValue)
    {
        PersistenceManager pm = getPM();
        // find the book to update.
        Query q = pm.newQuery(Book.class, field+" == val");
        q.declareParameters("String val");
        q.setCandidates(pm.getExtent(Book.class,true));
        Collection result = (Collection)q.execute(fieldValue);
        if (result.size()<1) {
            throw new RuntimeException(field+" not found: "+fieldValue);
        } else if (result.size()>1) {
            throw new RuntimeException(field+" not unique: "+fieldValue);
        }
        Book book = (Book)result.iterator().next();
        return book;
    }

    protected final Book findBook()
    {
        Book book = null;
        try {
            book = findBook("ISBN",this.findISBN);
        } catch (Exception e) {
            book = findBook("title",this.findTitle);
        }
        return book;
    }

    /**
     * Find all copies of a publication.
     */
    protected Copy[] findCopies(Publication publication)
    {
        PersistenceManager pm = getPM();
        // find all copies for a publication
        Query q = pm.newQuery(Copy.class, "copyOf == val");
        q.declareParameters("com.corejdo.casestudy.model.Publication val");
        q.setCandidates(pm.getExtent(Copy.class,true));
        Collection result = (Collection)q.execute(publication);
        Copy copies[] = new Copy[result.size()];
        result.toArray(copies);
        return copies;
    }

    public void setFindTitle(String findTitle)
    {
        this.findTitle = findTitle;
    }
    public void setFindISBN(String findISBN)
    {
        this.findISBN = findISBN;
    }
    private String findTitle;
    private String findISBN;
}