package com.corejdo.casestudy.usecase;


import com.corejdo.casestudy.model.*;
import com.corejdo.casestudy.tools.CmdLine;

import javax.jdo.*;

import java.util.*;
import java.text.DateFormat;
import java.text.ParseException;

/**
 * A copy of a book is searched and marked as "borrowed".
 * @author Heiko Bobzin, Keiron McCammon, Sameer Tyagi, Michael Vorburger
 * @version 1.0
 */

public class BorrowPublication extends BorrowReturn
{
    public static void main(String[] args)
    {
        new BorrowPublication().runCmdLine(args);
    }

    /**
     * Command line version of the book editor.
     */
    protected void run(String[] args)
    {
        setFindISBN(CmdLine.getStringVar("Find ISBN","1-2153-1882-3"));
        execute();
        System.out.println("Take book at "+location);
    }

    public final long borrowTime = 1000L*60L*10L; // ten minutes

    protected void process(Book book)
    {
        Copy copy[] = findCopies(book);
        for (int i = 0; i < copy.length; i++) {
            Copy c = copy[i];
            if (c.borrower == null) {
                c.borrower = getContext().user;
                c.borrowDate = new Date(); // now.
                c.returnDate = new Date(c.borrowDate.getTime()+borrowTime);
                this.returnDate = c.returnDate.toString();
                this.location = c.location;
                return;
            }
        }
        throw new UseCaseException("No copy available. Please ask clerk.");
    }

}