package com.corejdo.casestudy.usecase;

import com.corejdo.casestudy.model.*;
import com.corejdo.casestudy.tools.*;

/**
 * This class gets detailed information about a book.
 * It is a good example for information hiding. The actual book data
 * in the persistent model Book class uses a User field for the
 * borrower information, but unauthorized users must
 * not be able to see detailed information about borrowers.
 *
 * @author Heiko Bobzin, Keiron McCammon, Sameer Tyagi, Michael Vorburger
 * @version 1.0
 */
public class DetailedBook extends BookOperation
{

    public DetailedBook()
    {
    }

    public static void main(String[] args)
    {
        new DetailedBook().runCmdLine(args);
    }

    /**
     * Command line version of the book editor.
     */
    protected void run(String[] args)
    {
        setFindISBN(CmdLine.getStringVar("Find ISBN","928394-234-23444"));
        setFindTitle(CmdLine.getStringVar("Find Title",""));
        execute();
    }

    /**
     * First, looks up a book, then sets return value
     * for detailed book information. The implementation of this
     * method looks quite simple because JDO does a lot of things
     * for us, like fetching other objects on demand.
     */
    protected void _execute()
    {
        Book book = findBook();
        this.ISBN = book.ISBN;
        this.author = book.author;
        this.title = book.title;
        this.published = book.published.toString();
        this.firstPublished = book.firstPublished.toString();
        Copy copies[] = findCopies(book);
        availableCopies = 0;
        for (int i = 0; i < copies.length; i++) {
            if (copies[i].borrower == null) availableCopies++;
        }
        this.isBorrowed = availableCopies > 0;
    }

    public String getAuthor()
    {
        return author;
    }
    public int getAvailableCopies()
    {
        return availableCopies;
    }
    public String getFirstPublished()
    {
        return firstPublished;
    }
    public String getISBN()
    {
        return ISBN;
    }
    public boolean isIsBorrowed()
    {
        return isBorrowed;
    }
    public String getPublished()
    {
        return published;
    }
    public String getTitle()
    {
        return title;
    }

    String ISBN;
    String author;
    String title;
    String published;
    String firstPublished;
    int availableCopies;
    boolean isBorrowed;
}