package com.corejdo.casestudy.usecase;

import com.corejdo.casestudy.model.*;
import com.corejdo.casestudy.tools.CmdLine;

import javax.jdo.*;

import java.util.*;
import java.text.DateFormat;
import java.text.ParseException;

/**
 * This class is used to change user properties.
 *
 * @author Heiko Bobzin, Keiron McCammon, Sameer Tyagi, Michael Vorburger
 * @version 1.0
 */

public class EditUser extends UserOperation
{
    public static void main(String[] args)
    {
        new EditUser().runCmdLine(args);
    }

    /**
     * Command line version of the user management.
     *
     */
    protected void run(String[] args)
    {
        setFindUser(CmdLine.getStringVar("Find User Id","hb"));
        setLoad();
        try {
            execute();
        }
        catch (UserNotFoundException e)
        {
            System.out.println("User not found.");
            add = CmdLine.getBooleanVar("Add",false);
            if (!add) return;
        }
        setFirstName(CmdLine.getStringVar("First name",firstName));
        setLastName(CmdLine.getStringVar("Last name",lastName));
        setPassword(CmdLine.getStringVar("Password",password));
        setCanBorrow(CmdLine.getBooleanVar("May borrow",canBorrow));
        setCanManage(CmdLine.getBooleanVar("May manage publications",canManage));
        setCanModifyUser(CmdLine.getBooleanVar("May manage users",canModifyUser));

		if (add) setAdd();
         else setUpdate();
        execute();
    }


    public void setLoad()
    {
        this.update = false;
        this.add = false;
    }

    public void setUpdate()
    {
        this.update = true;
        this.add = false;
    }

    public void setAdd()
    {
        this.update = true;
        this.add = true;
    }


    public boolean isAllowed()
    {
        return getContext().userRights.canModifyUser();
    }
    /**
     * First, looks up a book, then updates the fields with
     * the values of this bean.
     */
    protected void _execute()
    {
        User user;
        if (add) {
            user = new User();
            user.setId(this.getFindUser());
        } else {
            user = findUser();
        }
        if (update || add) {
            user.setLastName(this.lastName);
            user.setFirstName(this.firstName);
            if (this.password.length() > 0) user.setPassword(this.password);
            Rights rights = user.getRights();

            rights.setBorrow(canBorrow ? Right.ALLOWED : Right.DENIED);
            rights.setManage(canManage ? Right.ALLOWED : Right.DENIED);
            rights.setModifyUser(canModifyUser ? Right.ALLOWED : Right.DENIED);
            if (add) {
                getPM().makePersistent(user);
            }
        } else {
            this.lastName = user.getLastName();
            this.firstName = user.getFirstName();
            this.password = "";
            this.canBorrow = user.getRights().canBorrow();
            this.canModifyUser = user.getRights().canModifyUser();
            this.canManage = user.getRights().canManage();
        }
    }

    public String getFirstName()
    {
        return firstName;
    }
    public void setFirstName(String firstName)
    {
        this.firstName = firstName;
    }
    public String getId()
    {
        return id;
    }
    public String getLastName()
    {
        return lastName;
    }
    public void setLastName(String lastName)
    {
        this.lastName = lastName;
    }
    public void setPassword(String password)
    {
        this.password = password;
    }
    public boolean isCanBorrow()
    {
        return canBorrow;
    }
    public void setCanBorrow(boolean canBorrow)
    {
        this.canBorrow = canBorrow;
    }
    public boolean isCanManage()
    {
        return canManage;
    }
    public void setCanManage(boolean canManage)
    {
        this.canManage = canManage;
    }
    public void setCanModifyUser(boolean canModifyUser)
    {
        this.canModifyUser = canModifyUser;
    }
    public boolean isCanModifyUser()
    {
        return canModifyUser;
    }

    private String firstName;
    private String lastName;
    private String id;
    private String password;
    private boolean canManage;
    private boolean canBorrow;
    private boolean canModifyUser;

    private boolean update = false;
    private boolean add = false;


}