package com.corejdo.casestudy.usecase;

import com.corejdo.casestudy.tools.CmdLine;
import com.corejdo.casestudy.model.*;
import javax.jdo.*;
import java.util.*;

/**
 * This class lists publications.
 *
 * Compared to the ListBooks operation, this one can only return
 * formatted text or HTML data. To provide links in the
 * table, a "Details" URL can be set, which is the prefix for
 * the HTML links.
 * @author Heiko Bobzin, Keiron McCammon, Sameer Tyagi, Michael Vorburger
 * @version 1.0
 */

public class ListPublications
    extends AbstractUseCase
{
    int startNumber = 0;
    int count = 20;

    /**
     */
    String result[];

    String prefix = "";

    Extent extent;

    /**
     * Sets the start offset. Since JDO does not support a "seek" operation on
     * extents, we implemented our own by simply calling iterator.next().
     * @param i
     */
    public void setStartNumber(int i)
    {
        startNumber = i;
    }

    /**
     * Sets the number of entries returned by this operation.
     * @param i number of entries
     */
    public void setCount(int i)
    {
        count = i;
    }

    /**
     * Iterates over elements of the book Extent.
     * Since JDO does not provide a "seek" operation, we implemented it
     * by simply calling iterator.next() up to the start position.
     */
    protected void _execute()
    {
        extent = getPM().getExtent(Publication.class,true);
        Query query = getPM().newQuery(Publication.class, "true");
        query.setOrdering("title ascending");
        query.setCandidates(extent);
        Collection queryResult = (Collection)query.execute();
        Iterator iter = queryResult.iterator();
        int i = this.startNumber;
        while (i-- > 0 && iter.hasNext()) iter.next();
        i = this.count;

        ArrayList r = new ArrayList();
        while (i-- > 0 && iter.hasNext()) {
            Publication publication = (Publication)iter.next();
            r.add(new String(publication.toHTML(prefix)));
        }
        this.result = new String[r.size()];
        r.toArray(result);
        query.closeAll();
    }

    /**
     * Command line version.
     */
    public static void main(String[] args) {
        new ListPublications().runCmdLine(args);
    }

    protected void run(String[] args) {
        setStartNumber(CmdLine.getIntVar("Start at",0));
        setCount(CmdLine.getIntVar("Count",10));
        execute();
        System.out.println("Result: ");
        String[] result = getResult();
        for (int i = 0; i < result.length; i++) {
            System.out.println(""+i+": "+result[i]);
        }
    }

    /**
     * The result is a list of Strings
     */
    public String[] getResult()
    {
        return result;
    }
    public int getCount()
    {
        return count;
    }
    public int getStartNumber()
    {
        return startNumber;
    }
    public String getPrefix()
    {
        return prefix;
    }
    public void setPrefix(String prefix)
    {
        this.prefix = prefix;
    }
}