package com.corejdo.casestudy.usecase;

import com.corejdo.casestudy.model.*;
import com.corejdo.casestudy.tools.CmdLine;

import javax.jdo.*;
import java.util.*;
/**
 * This class provides application-based security checks. In the example
 * database level security is not used, instead our own application-specific
 * right management is implemented on top of JDO.
 * When the user logs on, the session context is updated. Other
 * application operations, that need information about the user will
 * retrieve the user data via the context reference. In this case, JDO
 * might reload or refresh the data from the database or the implementations
 * internal cache.
 *
 * @author Heiko Bobzin, Keiron McCammon, Sameer Tyagi, Michael Vorburger
 * @version 1.0
 */

public class Login extends AbstractUseCase
{
    /**
     * Tests the login mechanisms.
     * @param args not used.
     */
    public void main(String args[])
    {
        new Login().runCmdLine(args);
    }

    /**
     * Tests the login mechanisms.
     */
    protected void run(String[] args)
    {
        setUserId(CmdLine.getStringVar("UserId",""));
        setPassword(CmdLine.getStringVar("Password",""));
        execute();
    }

    private void error()
    {
        throw new UseCaseException("Illegal user or password.");
    }

    /**
     * This method is called by the base class in the
     * context of an active JDO transaction.
     */
    protected void _execute()
    {
        User user = null;
        if (this.userId == null || this.userId.length() == 0) {
            // log off;
            getContext().userRights = new Rights(); // default
        } else {
            // log in;
            user = findUser();
            if (!user.checkPassword(password)) error();
            getContext().userRights = user.getRights().copy();
        }
        getContext().user = user;
    }

    public boolean isLoggedIn()
    {
        return getContext().user != null;
    }

    /**
     * Initializes the database with a primary (super) user.
     */
    protected void checkInitialUser()
    {
        PersistenceManager pm = getPM();
        Extent e = pm.getExtent(User.class,true);
        if (e.iterator().hasNext()) {
            return ;
        }
        User u = new User();
        u.setFirstName("Heiko");
        u.setLastName("Bobzin");
        u.setPassword("hb");
        u.setId("hb");

        pm.makePersistent(u);
        pm.currentTransaction().commit();
        pm.currentTransaction().begin();
    }

    /**
     * Finds a user object in the database.
     * @return user found
     */
    protected User findUser()
    {
        checkInitialUser();
        PersistenceManager pm = getPM();
        // find the book to update.
        Query q = pm.newQuery(User.class, "id == val");
        q.declareParameters("String val");
        q.setCandidates(pm.getExtent(User.class,true));
        Collection result = (Collection)q.execute(userId);
        if (result.size() != 1) error();
        User user = (User)result.iterator().next();
        return user;
    }


    public void setUserId(String userId)
    {
        this.userId = userId;
    }
    public void setPassword(String password)
    {
        this.password = password;
    }
    private String userId;
    private String password;
}