package com.corejdo.casestudy.usecase;



import com.corejdo.casestudy.model.*;
import com.corejdo.casestudy.tools.CmdLine;

import javax.jdo.*;

import java.util.*;
import java.text.DateFormat;
import java.text.ParseException;

/**
 * Get status of user.
 * Returns number of borrowed books, date of return, etc.
 * @author Heiko Bobzin, Keiron McCammon, Sameer Tyagi, Michael Vorburger
 * @version 1.0
 */

public class UserStatus extends AbstractUseCase
{
    public static void main(String[] args)
    {
        new UserStatus().runCmdLine(args);
    }

    /**
     * Command line version.
     */
    protected void run(String[] args)
    {
        execute();
        for (int i = 0; i < info.length; i++) {
            System.out.println("Title:  "+info[i].title);
            System.out.println("Return: "+info[i].returnDate);
        }
    }

    protected void _execute()
    {
        // find copies and books currently borrowed by this user:
        Copy copies[] = findCopies(getContext().user);
        info = new BorrowInfo[copies.length];
        for (int i = 0; i < copies.length; i++) {
            info[i] = new BorrowInfo();
            info[i].returnDate = copies[i].returnDate.toString();
            info[i].title = copies[i].copyOf.title;
            info[i].timeOver = copies[i].returnDate.after(new Date());
        }
    }

    /**
     * Find all copies borrowed by this user.
     */
    protected Copy[] findCopies(User user)
    {
        PersistenceManager pm = getPM();
        // find all copies of a user.
        Query q = pm.newQuery(Copy.class, "borrower == val");
        q.declareParameters("com.corejdo.casestudy.model.User val");
        q.setCandidates(pm.getExtent(Copy.class,true));
        Collection result = (Collection)q.execute(user);
        Copy copies[] = new Copy[result.size()];
        result.toArray(copies);
        return copies;
    }
    public BorrowInfo[] getInfo()
    {
        return info;
    }

    public class BorrowInfo
    {
        public String title;
        public String returnDate;
        public boolean timeOver;
    }

    BorrowInfo info[];
}