package com.corejdo.examples.chapter3;

import java.util.Properties;
import javax.jdo.*;

import com.corejdo.examples.util.PersistenceManagerFactoryHelper;
import com.corejdo.examples.model.Author;

/**
 * <p>This is a simple example to show how to create and persist 
 * a single instance of a persistence capable class within a
 * transaction.</p>
 * <p>It shows how to use <code>PersistenceManagerFactory</code>
 * to get a <code>PersistenceManager</code> instance. It then gets
 * the current <code>Transaction</code> and uses it to begin and
 * commit a transaction. The <code>makePersistent()</code> method is used
 * to make an instance of the <code>Author</code> class persistent.</p>
 * <p>It gets a <code>PersistenceManagerFactory</code> instance via the
 * {@link com.corejdo.examples.util.PersistenceManagerFactoryHelper} class,
 * therefore <code>jdo.properties</code> system property should be set 
 * to a valid properties file for the JDO implementation being used.</p>
 * <p>Before this example can be run a database should be created and
 * if necessary the schema for the <code>Author</code> class defined.
 * After the example has been run use the appropriate database browsing tools
 * to confirm the <code>Author</code> instance has been persisted.</p> 
 * 
 * @author mccammon
 * @see com.corejdo.examples.util.PersistenceManagerFactoryHelper
 * @see com.corejdo.examples.model.Author
 *
 */
public final class CreateExample {

  /**
   * <p>Used to run the example. No command line arguments are required.</p>
   * 
   * @param args command line arguments
   */
  public static void main(String[] args) {

    PersistenceManagerFactory pmf =
      PersistenceManagerFactoryHelper.getPersistenceManagerFactory();

    PersistenceManager pm = pmf.getPersistenceManager();

    Transaction tx = pm.currentTransaction();

    tx.begin();

    Author author = new Author("Keiron McCammon");

    pm.makePersistent(author);

    tx.commit();

    pm.close();
  }
  
  private CreateExample() {}
}
