package com.corejdo.examples.chapter3;

import java.util.*;
import javax.jdo.*;

import com.corejdo.examples.util.PersistenceManagerFactoryHelper;
import com.corejdo.examples.model.Author;

/**
 * <p>This is a simple example to show how to delete a persistent
 * object within a transaction.</p>
 * <p>It uses a <code>Query</code> to find an <code>Author</code> with the
 * name "Keiron McCammon", gets the first matching instance, uses the
 * <code>deletePersistent()</code> to delete it and commits the transaction.</p>
 * <p>It gets a <code>PersistenceManagerFactory</code> instance via the
 * {@link com.corejdo.examples.util.PersistenceManagerFactoryHelper} class,
 * therefore <code>jdo.properties</code> system property should be set 
 * to a valid properties file for the JDO implementation being used.</p>
 * <p>Before this example can be run a database should be created and
 * if necessary the schema for the <code>Author</code> class defined.
 * An <code>Author</code> instance with the name "Keiron McCammon"
 * needs to already exist in the database, this can be created using 
 * {@link com.corejdo.examples.chapter3.CreateExample CreateExample}.
 * After the example has been run use the appropriate database browsing tools
 * to confirm the <code>Author</code> instance has been deleted.</p> 
 * 
 * @author mccammon
 * @see com.corejdo.examples.util.PersistenceManagerFactoryHelper
 * @see com.corejdo.examples.model.Author
 * @see com.corejdo.examples.chapter3.CreateExample
 *
 */
public final class DeleteExample {

  /**
   * <p>Used to run the example. No command line arguments are required.</p>
   * 
   * @param args command line arguments
   */
  public static void main(String[] args) {

    PersistenceManagerFactory pmf =
      PersistenceManagerFactoryHelper.getPersistenceManagerFactory();

    PersistenceManager pm = pmf.getPersistenceManager();

    Transaction tx = pm.currentTransaction();

    tx.begin();

    Query query = pm.newQuery(Author.class, "name == \"Keiron McCammon\"");

    Collection authors = (Collection) query.execute();

    Author author = (Author) authors.iterator().next();

    pm.deletePersistent(author);

    //query.close(authors);

    tx.commit();

    pm.close();
  }
  
  private DeleteExample() {}
}
