package com.corejdo.examples.chapter3;

import java.util.Properties;
import javax.jdo.*;

/**
 * <p>This is a simple example to show how to use <code>JDOHelper</code>
 * to get a <code>PersistenceManagerFactory</code> instance based on a set
 * of hardcoded properties and then get a <code>PersistenceManager</code>
 * instance and close it. This example doesn't actually do anything with the
 * datastore other than open and close a connection.</p>
 * <p>Before this example can be run the source code should be modified
 * to specify values for the properties that are valid for the JDO 
 * implementation being used.</p>
 * 
 * @author mccammon
 *
 */
public final class MakeConnectionExample {

  /**
   * <p>Used to run the example. No command line arguments are required.</p>
   * 
   * @param args command line arguments
   */
  public static void main(String[] args) {

    Properties properties = new Properties();

    /*
     * Replace "XXX" with appropriate options for JDO implementation
     */
    properties.put("javax.jdo.PersistenceManagerFactoryClass", "XXX");
    properties.put("javax.jdo.option.ConnectionURL", "XXX");
    properties.put("javax.jdo.option.ConnectionUserName", "XXX");
    properties.put("javax.jdo.option.ConnectionPassword", "XXX");

    PersistenceManagerFactory pmf =
      JDOHelper.getPersistenceManagerFactory(properties);

    PersistenceManager pm = pmf.getPersistenceManager();

    /* Do something interesting */

    pm.close();
  }
  
  private MakeConnectionExample() {}
}
