package com.corejdo.examples.chapter3;

import java.util.Properties;
import java.io.FileInputStream;
import javax.jdo.*;

/**
 * <p>This is a simple example to show how to use <code>JDOHelper</code> 
 * to get a <code>PersistenceManagerFactory</code> instance based on 
 * a set of propeties that have been read from a file whose name is
 * specified using a system property called "<code>jdo.properties</code>".</p>
 * <p>This example has the advantage that the properties used to get the
 * <code>PersistenceManagerFactory</code> instance aren't hardcoded and can
 * be specified at runtime. This example doesn't actually do anything 
 * with the datastore other than open and close  connection.</p>
 * The <code>jdo.properties</code> system property should be set 
 * to a valid properties file for the JDO implementation being used.
 * The properties file should at least contain the 
 * <code>javax.jdo.PersistenceManagerFactoryClass</code> property.</p>
 * 
 * @author mccammon
 *
 */
public final class MakeConnectionFromFileExample {

  /**
   * <p>Used to run the example. No command line arguments are required.</p>
   * 
   * @param args command line arguments
   */
  public static void main(String[] args) {

    String filename = System.getProperty("jdo.properties");

    if (filename == null) {

      throw new 
        JDOFatalUserException("System property 'jdo.properties' not defined");
    }

    Properties properties = new Properties();

    try {

      properties.load(new FileInputStream(filename));
    }

    catch (java.io.IOException e) {

      throw new
        JDOFatalUserException("Error reading '" + filename + "'", e);
    }

    PersistenceManagerFactory pmf =
      JDOHelper.getPersistenceManagerFactory(properties);
  
    PersistenceManager pm = pmf.getPersistenceManager();

    /* Do something interesting */
  
    pm.close();
  }
  
  private MakeConnectionFromFileExample() {}
}
