package com.corejdo.examples.chapter3;

import java.util.Properties;
import javax.jdo.*;

/**
 * <p>This is a simple example to show how use <code>JDOHelper</code>
 * to get a <code>PersistenceManagerFactory</code> instance based on 
 * system properties.</p>
 * <p>This example has the advantage that the properties used to get the
 * <code>PersistenceManagerFactory</code> instance aren't hardcoded and can
 * be specified at runtime. This example doesn't actually do anything 
 * with the datastore other than open and close  connection.</p>
 * The <code>javax.jdo.PersistenceManagerFactoryClass</code>, 
 * <code>javax.jdo.option.ConnectionURL</code>,
 * <code>javax.jdo.option.ConnectionUserName</code>,
 * <code>javax.jdo.option.ConnectionPassword</code>, system properties
 * should be defined as appropriate for the JDO implementation being used.</p>
 * 
 * @author mccammon
 *
 */
public final class MakeConnectionFromSystemPropertiesExample {

  /**
   * <p>Used to run the example. No command line arguments are required.</p>
   * 
   * @param args command line arguments
   */
  public static void main(String[] args) {

    Properties properties = new Properties();
    
    properties.put(
      "javax.jdo.PersistenceManagerFactoryClass",
      System.getProperty("javax.jdo.PersistenceManagerFactoryClass"));
    properties.put(
      "javax.jdo.option.ConnectionURL",
      System.getProperty("javax.jdo.option.ConnectionURL"));
    properties.put(
      "javax.jdo.option.ConnectionUserName",
      System.getProperty("javax.jdo.option.ConnectionUserName"));
    properties.put(
      "javax.jdo.option.ConnectionPassword",
      System.getProperty("javax.jdo.option.ConnectionPassword"));

    try {

      PersistenceManagerFactory pmf =
        JDOHelper.getPersistenceManagerFactory(properties);

      PersistenceManager pm = pmf.getPersistenceManager();

      pm.close();
    } catch (JDOException e) {

      e.printStackTrace();
    }
  }
  
  private MakeConnectionFromSystemPropertiesExample() {}
}
