package com.corejdo.examples.chapter3;

import java.util.*;
import javax.jdo.*;

import com.corejdo.examples.util.PersistenceManagerFactoryHelper;
import com.corejdo.examples.model.Author;

/**
 * <p>This simple example uses an <code>Extent</code> to iterate through
 * all the persistent objects in the datastore that belong to the 
 * <code>Author</code> class.</p>
 * <p>It gets a <code>PersistenceManagerFactory</code> instance via the
 * {@link com.corejdo.examples.util.PersistenceManagerFactoryHelper} class,
 * therefore <code>jdo.properties</code> system property should be set 
 * to a valid properties file for the JDO implementation being used.</p>
 * <p>Before this example can be run a database should be created and
 * if necessary the schema for the <code>Author</code> class defined.
 * At least one <code>Author</code> instance needs to already exist in the
 * database, this can be created using 
 * {@link com.corejdo.examples.chapter3.CreateExample CreateExample}.</p>
 * 
 * @author mccammon
 * @see com.corejdo.examples.util.PersistenceManagerFactoryHelper
 * @see com.corejdo.examples.model.Author
 * @see com.corejdo.examples.chapter3.CreateExample
 *
 */
public final class ReadByExtentExample {

  /**
   * <p>Used to run the example. No command line arguments are required.</p>
   * 
   * @param args command line arguments
   */
  public static void main ( String[] args ) {

    PersistenceManagerFactory pmf =
      PersistenceManagerFactoryHelper.getPersistenceManagerFactory();

    PersistenceManager pm = pmf.getPersistenceManager();

    Transaction tx = pm.currentTransaction();
    
    tx.begin();
    
    Extent extent = pm.getExtent(Author.class, true);
    
    Iterator authors = extent.iterator();
    
    while (authors.hasNext()) {
        
      Author author = (Author) authors.next();
    
      String name = author.getName();
    
      System.out.println("Author's name is '" + name + "'.");
    }
    
    extent.close(authors);
    
    tx.commit();
    
    pm.close();
  }
  
  private ReadByExtentExample() {}
}
