package com.corejdo.examples.chapter3;

import java.util.*;
import javax.jdo.*;

import com.corejdo.examples.util.PersistenceManagerFactoryHelper;
import com.corejdo.examples.model.Author;

/**
 * <p>This simple example uses a <code>Query</code> to find a previously
 * created <code>Author</code> instance, it then changes the name of the
 * <code>Author</code> and commits the transaction.</p>
 * <p>It gets a <code>PersistenceManagerFactory</code> instance via the
 * {@link com.corejdo.examples.util.PersistenceManagerFactoryHelper} class,
 * therefore <code>jdo.properties</code> system property should be set 
 * to a valid properties file for the JDO implementation being used.</p>
 * <p>Before this example can be run a database should be created and
 * if necessary the schema for the <code>Author</code> class defined.
 * At least one <code>Author</code> instance needs to already exist in the
 * database with the name "Keiron McCammon", this can be created using
 * {@link com.corejdo.examples.chapter3.CreateExample CreateExample}.</p>
 * 
 * @author mccammon
 * @see com.corejdo.examples.util.PersistenceManagerFactoryHelper
 * @see com.corejdo.examples.model.Author
 * @see com.corejdo.examples.chapter3.CreateExample
 *
 */
public final class UpdateExample {

  /**
   * <p>Used to run the example. No command line arguments are required.</p>
   * 
   * @param args command line arguments
   */
  public static void main ( String[] args ) {

    PersistenceManagerFactory pmf =
      PersistenceManagerFactoryHelper.getPersistenceManagerFactory();

    PersistenceManager pm = pmf.getPersistenceManager();

    Transaction tx = pm.currentTransaction();
    
    tx.begin();
    
    /*
     * Find the Author by name
     */
    Query query = pm.newQuery(Author.class, "name == \"Keiron McCammon\"");
    
    Collection authors = (Collection) query.execute();
    
    Author author = (Author) authors.iterator().next();
    
    query.close(authors);
    
    /*
     * Change the Author's name
     */
    author.setName("Sameer Tyagi");
    
    tx.commit();

    tx.begin();
 
    String name = author.getName();

    /*
     * Validate that the Author's name has changed in the datastore
     */           
    System.out.println("Author's name is '" + name + "'.");
    
    tx.commit();
    
    pm.close();
  }
  
  private UpdateExample() {}
}
