package com.corejdo.examples.chapter5;

import java.util.*;
import javax.jdo.*;

import com.corejdo.examples.util.*;
import com.corejdo.examples.model.*;

/**
 * <p>This example shows how to use an <code>Extent</code> to iterate through
 * each instance of a class in the datastore.</p>
 * <p>It gets a <code>PersistenceManagerFactory</code> instance via the
 * {@link com.corejdo.examples.util.PersistenceManagerFactoryHelper} class,
 * therefore <code>jdo.properties</code> system property should be set 
 * to a valid properties file for the JDO implementation being used.</p>
 * <p>Before this example can be run a database should be created and
 * if necessary the schema for the <code>Book</code> class defined.
 * There should be at least one <code>Book</code> instance in the database.</p>
 * 
 * @author mccammon
 * @see com.corejdo.examples.util.PersistenceManagerFactoryHelper
 * @see com.corejdo.examples.model.Book
 *
 */
public class ExtentExample {

  /**
   * <p>Used to run the example. No command line arguments are required.</p>
   * 
   * @param args command line arguments
   */
  public static void main(String[] args) {

    PersistenceManagerFactory pmf =
      PersistenceManagerFactoryHelper.getPersistenceManagerFactory();

    PersistenceManager pm = pmf.getPersistenceManager();

    Transaction tx = pm.currentTransaction();
    
    tx.begin();
    
    Extent extent = pm.getExtent(Book.class, true);
    
    Iterator books = extent.iterator();
    
    System.out.println("Listing of all books:");
    
    while (books.hasNext()) {
    
      Book book = (Book) books.next();
    
      System.out.println("  " + book.getTitle());
    }
    
    extent.close(books);
    
    tx.commit();
    
    pm.close();
  }
  
  private ExtentExample() {}
}
