package com.corejdo.examples.chapter5;

import java.util.*;
import javax.jdo.*;

import com.corejdo.examples.util.*;
import com.corejdo.examples.model.*;

/**
 * <p>The following example shows how persistence by reachability works.</p>
 * <p>It creates <code>Author</code>, <code>Address</code>, <code>Publisher</code>
 * and <code>Book</code> instances. The <code>Book</code> instance is added to both the
 * <code>Publisher</code> and <code>Author</code> instances and the
 * <code>Author</code> instance is made persistent. Because the <code>Author</code>
 * instance references the <code>Address</code> instance and <code>Book</code>
 * instance which in turn references the <code>Publisher</code> instance they are
 * all made persistent implicitly by reachability.</p>
 * <p>It gets a <code>PersistenceManagerFactory</code> instance via the
 * {@link com.corejdo.examples.util.PersistenceManagerFactoryHelper} class,
 * therefore <code>jdo.properties</code> system property should be set 
 * to a valid properties file for the JDO implementation being used.</p>
 * <p>Before this example can be run a database should be created and
 * if necessary the schema for the <code>Author</code>, <code>Address</code>,
 * <code>Publisher</code> and <code>Book</code> classes defined. After
 * the example has been run use the appropriate database browsing tools to
 * confirm the instances have been created.</p> 
 * 
 * @author mccammon
 * @see com.corejdo.examples.util.PersistenceManagerFactoryHelper
 * @see com.corejdo.examples.model.Address
 * @see com.corejdo.examples.model.Author
 * @see com.corejdo.examples.model.Book
 * @see com.corejdo.examples.model.Publisher
 *
 */
public class MakePersistentExample {

  /**
   * <p>Used to run the example. No command line arguments are required.</p>
   * 
   * @param args command line arguments
   */
  public static void main(String[] args) {

    PersistenceManagerFactory pmf =
      PersistenceManagerFactoryHelper.getPersistenceManagerFactory();

    PersistenceManager pm = pmf.getPersistenceManager();

    Transaction tx = pm.currentTransaction();

    tx.begin();

    Author author =
      new Author(
        "Keiron McCammon",
        new Address("6539 Dumbarton Circle", "Fremont", "CA", "94555"));

    Publisher publisher = new Publisher("Sun Microsystems Press");

    Book book = new Book("Core Java Data Objects", "0-13-140731-7");

    author.addBook(book);

    publisher.addBook(book);

    pm.makePersistent(author);

    tx.commit();

    pm.close();
  }

  private MakePersistentExample() {}
}
