package com.corejdo.examples.chapter5;

import java.util.Properties;
import java.io.*;
import javax.jdo.*;

/**
 * <p>This example shows how to create a singleton class to manage the
 * explicit creation of a PersistenceManagerFactory instance.</p>
 * <p>The <code>initialize()</code> method creates a
 * <code>PersistenceManagerFactory</code> instance using the
 * <code>JDOHelper.getPersistenceManagerFactory()</code> method,
 * passing the connection URL, username and password as properties.<p>
 * 
 * @author mccammon
 *
 */
public class PMFSingletonExample {
  
  // PersistenceManagerFactory singleton
  private static PersistenceManagerFactory pmf;
  
  /**
   * <p>This method returns the singleton PersistenceManagerFactory.
   * If it the singleton hasn't been initialized it throws
   * JDOFatalUserException. The initialize() method should be called
   * before this method is used.</p>
   * 
   * @return the PersistenceManagerFactory instance
   */
  public static PersistenceManagerFactory getPersistenceManagerFactory() {
    
    if (pmf == null) {
      
     throw new JDOUserException("PersistenceManagerFactory not initialized.");
    }
    
    return pmf;
  }

  /**
   * <p>Creates a PersistenceManagerFactory based on the
   * specified properties and initializes the singleton.
   * The PersistenceManagerFactoryClass needs to be specified rather than "XXX".</p>
   * 
   * @param url the connection URL
   * @param name the user name for the datastore
   * @param password the password for the user
   */
  public static void intialize(String url, String name, String password) {

    Properties properties = new Properties();
    
    properties.put(
      "javax.jdo.PersistenceManagerFactoryClass", "XXX");
    properties.put(
      "javax.jdo.option.ConnectionURL", url);
    properties.put(
      "javax.jdo.option.ConnectionUserName", name);
    properties.put(
      "javax.jdo.option.ConnectionPassword", password);

    pmf = JDOHelper.getPersistenceManagerFactory(properties);
  }
  
  private PMFSingletonExample() {}
}
