package com.corejdo.examples.chapter5;

import javax.jdo.*;
import com.corejdo.examples.util.*;

/**
 * <p>This is a simple example to show to get a <code>PersistenceManager</code>
 * instance and ensure that any active transaction is rolled back and the 
 * <code>PersistenceManager</code> instance closed using a finally statement.
 * <p>It gets a <code>PersistenceManagerFactory</code> instance via the
 * {@link com.corejdo.examples.util.PersistenceManagerFactoryHelper} class,
 * therefore <code>jdo.properties</code> system property should be set 
 * to a valid properties file for the JDO implementation being used.</p>
 *
 * @author mccammon
 * @see com.corejdo.examples.util.PersistenceManagerFactoryHelper
 *
 */
public class PersistenceManagerExample {

  /**
   * <p>Used to run the example. No command line arguments are required.</p>
   * 
   * @param args command line arguments
   */
  public static void main(String[] args) {

    PersistenceManagerFactory pmf =
      PersistenceManagerFactoryHelper.getPersistenceManagerFactory();

    PersistenceManager pm = null;

    try {

      pm = pmf.getPersistenceManager();

      // Do something interesting

      pm.close();
    }

    finally {

      if (pm != null && !pm.isClosed()) {

        if (pm.currentTransaction().isActive()) {

          pm.currentTransaction().rollback();
        }

        pm.close();
      }
    }
  }
  
  private PersistenceManagerExample() {}
}
