package com.corejdo.examples.chapter5;

import java.util.*;
import javax.jdo.*;

import com.corejdo.examples.util.*;
import com.corejdo.examples.model.*;

/**
 * <p>This example shows how the <code>PersistenceManager.refresh()</code>
 * method can be used to re-retrieve the fields of a persistent object from
 * the datastore.</p>
 * <p>It gets a <code>PersistenceManagerFactory</code> instance via the
 * {@link com.corejdo.examples.util.PersistenceManagerFactoryHelper} class,
 * therefore <code>jdo.properties</code> system property should be set 
 * to a valid properties file for the JDO implementation being used.</p>
 * <p>Before this example can be run a database should be created and
 * if necessary the schema for the <code>Author</code> class defined.</p>
 * 
 * @author mccammon
 * @see com.corejdo.examples.util.PersistenceManagerFactoryHelper
 * @see com.corejdo.examples.model.Author
 *
 */
public class RefreshExample {

  /**
   * <p>Used to run the example. No command line arguments are required.</p>
   * 
   * @param args command line arguments
   */
  public static void main(String[] args) {

    PersistenceManagerFactory pmf =
      PersistenceManagerFactoryHelper.getPersistenceManagerFactory();

    PersistenceManager pm = pmf.getPersistenceManager();

    Transaction tx = pm.currentTransaction();

    tx.begin();

    Author author = new Author("Keiron McCammon");
        
    pm.makePersistent(author);

    tx.commit();
    
    tx.begin();

    System.out.println("Author's name is '" + author.getName() + "'.");

    author.setName("Sameer Tyagi");

    System.out.println("Author's name changed to '" + author.getName() + "'.");

    pm.refresh(author);

    System.out.println(
      "Author's name after refresh is '" + author.getName() + "'.");

    tx.commit();

    pm.close();
  }
  
  private RefreshExample() {}
}
