package com.corejdo.examples.chapter5;

import java.util.*;
import javax.jdo.*;

import com.corejdo.examples.util.*;
import com.corejdo.examples.model.*;

/**
 * <p>This example shows how to order the persistent objects returned by a query
 * based on field values.</p>
 * <p>It finds all <code>Book</code> instances with a given title an orders them
 * by their ISBN numbers.</p>
 * <p>It gets a <code>PersistenceManagerFactory</code> instance via the
 * {@link com.corejdo.examples.util.PersistenceManagerFactoryHelper} class,
 * therefore <code>jdo.properties</code> system property should be set 
 * to a valid properties file for the JDO implementation being used.</p>
 * <p>Before this example can be run a database should be created and
 * if necessary the schema for the <code>Book</code> class defined.</p> 
 * 
 * @author mccammon
 * @see com.corejdo.examples.util.PersistenceManagerFactoryHelper
 * @see com.corejdo.examples.model.Book
 *
 */
public class SimpleQueryWithOrderingExample {

  /**
   * <p>Used to run the example. No command line arguments are required.</p>
   * 
   * @param args command line arguments
   */
  public static void main(String[] args) {

    PersistenceManagerFactory pmf =
      PersistenceManagerFactoryHelper.getPersistenceManagerFactory();

    PersistenceManager pm = pmf.getPersistenceManager();

    Transaction tx = pm.currentTransaction();
    
    tx.begin();
    
    pm.makePersistent(new Book("Core Java Data Objects", "0-13-140731-7"));
    pm.makePersistent(new Book("Core Java Data Objects", "0-13-140731-8"));

    tx.commit();
    
    tx.begin();

    Query query = pm.newQuery(Book.class, "this.title == title");    
       
    query.declareParameters("String title");
    
    query.setOrdering("isbn ascending");
    
    Collection result = (Collection) query.execute("Core Java Data Objects");
    
    Iterator iter = result.iterator();
    
    while (iter.hasNext()) {
      
      Book book = (Book) iter.next();
      
      System.out.println(book.getTitle() + " - " + book.getISBN());
    }
    
    query.close(result);
    
    tx.commit();
    
    pm.close();
  }    
  
  private SimpleQueryWithOrderingExample() {}
}
