package com.corejdo.examples.chapter7;

import com.corejdo.examples.model.Author;
import com.corejdo.examples.util.PersistenceManagerFactoryHelper;

import javax.jdo.Query;
import java.util.Iterator;
import java.util.Collection;
import java.io.ObjectOutputStream;
import java.io.FileOutputStream;
import java.io.ObjectInputStream;
import java.io.FileInputStream;
import javax.jdo.*;

public class TemplateExample {

    public static void main(String args[]) {

        // The properties file contains all configuration
// properties
        PersistenceManagerFactory pmf =
                PersistenceManagerFactoryHelper.getPersistenceManagerFactory();

        PersistenceManager pm = pmf.getPersistenceManager();
// create and serialize the query
        if (args[0].equalsIgnoreCase("serialize")) {
            String filter = "books.contains(myfavouritebook) && " +
                    "(myfavouritebook.title==\"Learn Java Today\")";
            Query query = pm.newQuery(Author.class, filter);
            query.declareVariables("Book myfavouritebook");
            // close resources just to be safe
            query.closeAll();
            serializeQuery(query);
        } else if (args[0].equalsIgnoreCase("deserialize")) {


            // deserialize and execute

            Transaction tx = pm.currentTransaction();


            tx.begin();
            Object deserQuery = deserializeQuery();
            Query recreatedQuery = pm.newQuery(deserQuery);


            Collection results = (Collection) recreatedQuery.execute();
            if (results.isEmpty())
                System.out.println("No results found");
            else {

                Iterator iter = results.iterator();
                while (iter.hasNext()) {
                    Author author = (Author) iter.next();
                    String name = author.getName();
                    System.out.println("Author's name is " + name);
                    System.out.println("Author's address is " + author.getAddress());
                    System.out.println("Author's books are ");
                    Iterator books = author.getBooks().iterator();
                    while (books.hasNext())
                        System.out.println("Book:" + books.next());

                }
            }
            recreatedQuery.closeAll();


            tx.commit();
        }

    }


    /** Serialize and save the query object
     *
     * @param query a Query object saved to the file named "query.ser"
     */

    public static void serializeQuery(Query query) {
        try {
            ObjectOutputStream os = new ObjectOutputStream(new FileOutputStream("query.ser"));
            os.writeObject(query);
            os.close();
        } catch (Exception e) {
            System.out.println("An exception occurred during query serialization :" + e);
        }

    }

    /** Deserialize the query
     *
     * @return  a Query object read from the file named "query.ser"
     */
    public static Query deserializeQuery() {
        try {
            ObjectInputStream os = new ObjectInputStream(new FileInputStream("query.ser"));
            Query q = (Query) os.readObject();
            os.close();
            return q;
        } catch (Exception e) {
            System.out.println("An exception occurred during query de-serialization :" + e);
            return null;
        }

    }
}
